#import "CoreAnimationViewController.h"

@implementation CoreAnimationViewController

@synthesize img;

// viewDidLoad function is called once the app has finished loading 
- (void)viewDidLoad {
	
	// 1. In this example we are not using Interface Builder
	img = [[UIImageView alloc]initWithImage:[UIImage imageNamed:@"pizza.jpeg"]];
	[img setFrame:CGRectMake(0, 0, 100, 100)];
	
	// add a new UIImageView to the view with the function addSubView:(UIView *)view
	[self.view addSubview:img];
    [super viewDidLoad];
}

-(void)touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event{
	
	// 2. Get touch event 
	UITouch *myTouch = [touches anyObject];
	
	
	// 3.
	// begin the animations block:
    [UIView beginAnimations:@"moveTo" context:NULL];
	
	// define how long the animation should take, in seconds. 0.5 is half a second.
    [UIView setAnimationDuration:1];
	
	// optional: transitions form current state instead of jumping to the end of current animation cycle
	[UIView setAnimationBeginsFromCurrentState:YES];
	
	
	// 4. Set new center to the center point of myTouch
	[img setCenter:[myTouch locationInView:self.view]];
	
	/*
	// Set the new states you would like to animate to
	[img setFrame:CGRectMake(0, 0, 100, 100)];
    // or by changing its alpha value:
	[img setAlpha:0.5];
	// or by moving 
	[img setCenter:[myTouch locationInView:self.view]];
    // or by rotating it:
    img.transform = CGAffineTransformMakeRotation(45 * 180 / M_PI); // 45 deg, or radians * 180 / M_PI;
	
	// optional: Restores a view back to it's original angle
	img.transform = CGAffineTransformIdentity;
	
	 */
	 
	// optional: to execute code after the animation has finished, set the delegate:
    // with out this you can't call the animationDidStop() function
    [UIView setAnimationDelegate:self];
	
	// optional: set the animation curve:
    //   UIViewAnimationCurveEaseIn: begins slowly, then speeds up
    //   UIViewAnimationCurveEaseOut: begins fast, then slows down
    //   UIViewAnimationCurveEaseInOut: begins slowly, faster in the middle, slows down at end
    //   UIViewAnimationCurveLinear: same speed throughout
    [UIView setAnimationCurve: UIViewAnimationCurveEaseOut];
	
	
	// start animating!
    [UIView commitAnimations];
}


// 5. If you set setAnimationDelegate:self this function will be called at the end every Animation
- (void)animationDidStop:(NSString *)animID finished:(BOOL)didFinish context:(void *)context 
{
    // 6. Check the animID. Based on that ID call a new animation
	if ( [animID isEqualToString:@"moveTo"] ) {
        NSLog(@"moveTo animation finished.");		
		[UIView beginAnimations:@"Bounce" context:NULL];
		[UIView setAnimationDelegate:self];
		[UIView setAnimationBeginsFromCurrentState:YES];
		[UIView setAnimationCurve: UIViewAnimationCurveEaseOut];
		[UIView setAnimationDuration:.3];
		img.transform = CGAffineTransformMakeScale(1.5, 1.5);
		[UIView commitAnimations];
    }else if( [animID isEqualToString:@"Bounce"]){
		NSLog(@"Bounce animation finished.");		
		[UIView beginAnimations:@"ended" context:NULL];
		[UIView setAnimationCurve: UIViewAnimationCurveEaseIn];
		[UIView setAnimationDuration:.3];
		[UIView setAnimationBeginsFromCurrentState:YES];
		img.transform = CGAffineTransformMakeScale(1, 1);
		[UIView commitAnimations];
	
	} else if ( [animID isEqualToString:@"ended"] ) {
        NSLog(@"done moving.");
    } 
}

- (void)viewDidUnload {
	// 7. Release any retained subviews of the main view.
	[img release];
}

- (void)dealloc {
    [super dealloc];
}

@end
